/*
 * MemberServlet.java - base class for VolanoChat membership servlets.
 */

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.SQLException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;

/**
 * This class serves as a base class for the VolanoChat membership
 * database servlets.
 *
 * @version 1.0
 * @author  John Neffenger
 */
public class MemberServlet extends HttpServlet implements Constants {
    private   Connection connection = null;
    protected PreparedStatement statement = null;

    /**
     * Returns the servlet class name and given version.
     *
     * @return information about this servlet.
     */
    protected String getServletInfo(String version) {
        return getClass().getName() + " " + version;
    }

    /**
     * Initializes the servlet by loading the MySQL JDBC driver, establishing a
     * connection to the database, and preparing the query statement.
     *
     * @throws ServletException if an error occurs initializing the servlet.
     */
    protected void init(String query) throws ServletException {
        try {
            // Connect to the database and prepare the query statement.
            Class.forName(JDBC_DRIVER);
            connection = DriverManager.getConnection(JDBC_URL);
            statement = connection.prepareStatement(query);
        }
        catch (Exception e) {
            throw new ServletException(e);
        }
    }

    /**
     * Gets a mandatory servlet parameter.
     *
     * @param request the HTTP servlet request.
     * @param name    the name of the parameter to get.
     * @return the parameter value.
     * @throws ServletException if the parameter is not present or its value is
     *         the empty string.
     */
    protected String getParameter(HttpServletRequest request, String name)
        throws ServletException {
        String value = request.getParameter(name);
        if (value == null || value.length() == 0) {
            throw new ServletException("Undefined parameter: " + name);
        }
        return value;
    }

    /**
     * Destroys the servlet by closing the prepared statement and
     * the database connection.
     */
    public void destroy() {
        try {
            // Free the prepared statement and close the connection.
            if (statement != null) {
                statement.close();
            }
            if (connection != null) {
                connection.close();
            }
        }
        catch (SQLException e) {
            log(e.toString());
        }
    }
}
