/*
 * NameServlet.java - a sample VolanoChat member name servlet.
 */

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * This class serves as a sample VolanoChat membership database name servlet.
 *
 * @version 1.0
 * @author  John Neffenger
 */
public class NameServlet extends MemberServlet implements Constants {
    private static final String SERVLET_VERSION = "1.0";

    /**
     * Returns the servlet name and version.
     *
     * @return information about this servlet.
     */
    public String getServletInfo() {
        return getServletInfo(SERVLET_VERSION);
    }

    /**
     * Initializes the servlet by preparing the query statement.
     *
     * @throws ServletException if an error occurs initializing the servlet.
     */
    public void init() throws ServletException {
        init(NAME_QUERY);
    }

    /**
     * Processes an HTTP GET request.
     *
     * @param request  the HTTP servlet request.
     * @param response the HTTP servlet response.
     * @throws IOException if an input or output error occurs while processing
     *         the request.
     * @throws ServletException if the servlet is unable to process the request.
     */
    public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws ServletException, IOException {
        response.setContentType(CONTENT_TYPE);
        PrintWriter writer = new PrintWriter(response.getWriter());
        try {
            // Get the HTTP request parameters.
            String name = getParameter(request, NAME_PARAMETER);

            // If the given member name exists, return true.
            // Otherwise, return false.
            statement.setString(NAME_INDEX, name);
            ResultSet results = statement.executeQuery();
            writer.println(results.next() ? TRUE : FALSE);
            results.close();
        }
        catch (RuntimeException e) {
            throw e;
        }
        catch (Exception e) {
            writer.println(ERROR);
            writer.println(e);
        }
        writer.close();
    }
}
